#!/bin/sh
#
# Small script to generate a usable html index page for the html formatted
# info documentation included on TSL 2.0 and later.
# Released into the public doamin
# Christian H. Toldnes <christht@trustix.com> 2002-10-24
# Inital version: 0.1.0
#
# 0.1.1 : bugfix
# 0.1.2 : bugfix
# 0.1.3 : made more generic
# 0.1.4 : check for seperated html file(set) first, than unified page
# 0.1.5 : more robust release checking

# Some variables:
HTMLDIR="/usr/share/html/"
TOPPAGE="$HTMLDIR/.top.html"
BOTTOMPAGE="$HTMLDIR/.bottom.html"
INDEX="$HTMLDIR/index.html"

# This script does not take any arguments:
if [ ! -z "$1" ]; then
	echo "This script does not take any arguments."
	exit 1
fi

# Some sanity checks:
# Is this TSL?
if [ ! -f /etc/trustix-release ]; then
	if [ ! -f /etc/tawie-release ]; then
		echo "No /etc/trustix-release, something is wrong."
		exit 1
	fi
fi
# Does $HTMLDIR, $TOPPAGE and $BOTTOMPAGE exist?
if [ ! -d $HTMLDIR ]; then
	echo "Problem with $HTMLDIR, exiting"
	exit 1
fi
if [ ! -f $TOPPAGE ]; then
	echo "Problem with $TOPPAGE, exiting"
	exit 1
fi
if [ ! -f $BOTTOMPAGE ]; then
	echo "Problem with $BOTTOMPAGE, exiting"
	exit 1
fi

# now begin:
cat $TOPPAGE > $INDEX
for i in $(\ls -1 $HTMLDIR | cut -d/ -f1); do
	if [ -f $HTMLDIR/$i/index.html ]; then
		echo "<tr><td><a href=\"$i/index.html\">$i</a></td></tr>"
	elif [ -f $HTMLDIR/$i/$i.html ]; then
		echo "<tr><td><a href=\"$i/$i.html\">$i</a></td></tr>"
	fi
done >> $INDEX
cat $BOTTOMPAGE >> $INDEX
